@@ -106,6 +106,7 @@ class Image(
         dir: builtins.str,
         build_args: typing.Optional[typing.Sequence[BuildArg]] = None,
         file: typing.Optional[builtins.str] = None,
+        platform: typing.Optional[builtins.str] = None,
         registry: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -114,10 +115,15 @@ class Image(
         :param dir: The docker build context directory (where ``Dockerfile`` is).
         :param build_args: List of build args to pass to the build action.
         :param file: Path to Dockerfile.
+        :param platform: Set to specify the target platform for the build output, (for example, linux/amd64, linux/arm64, or darwin/amd64).
         :param registry: The registry URL to use. This will be used as the prefix for the image name. For example, if you have a local registry listening on port 500, you can set this to ``localhost:5000``. Default: "docker.io/library"
         '''
         props = ImageProps(
-            dir=dir, build_args=build_args, file=file, registry=registry
+            dir=dir,
+            build_args=build_args,
+            file=file,
+            platform=platform,
+            registry=registry,
         )
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -136,6 +142,7 @@ class Image(
         "dir": "dir",
         "build_args": "buildArgs",
         "file": "file",
+        "platform": "platform",
         "registry": "registry",
     },
 )
@@ -146,6 +153,7 @@ class ImageProps:
         dir: builtins.str,
         build_args: typing.Optional[typing.Sequence[BuildArg]] = None,
         file: typing.Optional[builtins.str] = None,
+        platform: typing.Optional[builtins.str] = None,
         registry: typing.Optional[builtins.str] = None,
     ) -> None:
         '''Props for ``Image``.
@@ -153,6 +161,7 @@ class ImageProps:
         :param dir: The docker build context directory (where ``Dockerfile`` is).
         :param build_args: List of build args to pass to the build action.
         :param file: Path to Dockerfile.
+        :param platform: Set to specify the target platform for the build output, (for example, linux/amd64, linux/arm64, or darwin/amd64).
         :param registry: The registry URL to use. This will be used as the prefix for the image name. For example, if you have a local registry listening on port 500, you can set this to ``localhost:5000``. Default: "docker.io/library"
         '''
         self._values: typing.Dict[str, typing.Any] = {
@@ -162,6 +171,8 @@ class ImageProps:
             self._values["build_args"] = build_args
         if file is not None:
             self._values["file"] = file
+        if platform is not None:
+            self._values["platform"] = platform
         if registry is not None:
             self._values["registry"] = registry
 
@@ -184,6 +195,12 @@ class ImageProps:
         result = self._values.get("file")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def platform(self) -> typing.Optional[builtins.str]:
+        '''Set to specify the target platform for the build output, (for example, linux/amd64, linux/arm64, or darwin/amd64).'''
+        result = self._values.get("platform")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     @builtins.property
     def registry(self) -> typing.Optional[builtins.str]:
         '''The registry URL to use.
